import emoji
import re


# region emoji
def is_emoji(s):
    for lang in emoji.UNICODE_EMOJI_ENGLISH:
        if s in emoji.UNICODE_EMOJI_ENGLISH[lang]: return True
    return False


def contains_emoji(txt: str):
    for c in txt:
        if is_emoji(c):
            return True
    return False


def contains_special_characters(txt: str):
    special_characters = "!@#$%^&*"
    count = 0
    for sc in special_characters:
        count += txt.count(sc)
        if count > 1:
            return True
    return bool(count)


def contains_mal_phrases(txt: str):
    phrases = ['sex', 'porn']
    count = 0
    for sc in phrases:
        count += txt.count(sc)
        if count > 1:
            return True
    return bool(count)


def is_validate(txt: str):
    if contains_emoji(txt=txt) or contains_special_characters(txt=txt) or contains_mal_phrases(txt=txt):
        return False
    return True
# endregion


# region regex
def validate_regex(regex: str, txt: str) -> bool:
    pattern = re.compile(regex)
    if re.match(regex, txt):
        return True
    else:
        return False
# endregion



from email_validator import validate_email, EmailNotValidError


def is_email_valid(email: str) -> (bool, str):
  try:
    valid = validate_email(email)

    email = valid.email
    return True
  except EmailNotValidError as e:
    return False




from typing import NamedTuple

import bcrypt


class PasswordHash(NamedTuple):
    hashed_password: str
    salt: str


def hash_password(password: str) -> PasswordHash:
    # Generate a salt and hash the password
    salt = bcrypt.gensalt()
    hashed_password = bcrypt.hashpw(password.encode('utf-8'), salt)

    # Return the hashed password as a utf-8 encoded string
    return PasswordHash(hashed_password.decode('utf-8'), salt.decode('utf-8'))


def check_password(password: str, hashed_password: str) -> bool:
    # Check if the provided password matches the hashed password
    return bcrypt.checkpw(password.encode('utf-8'), hashed_password.encode('utf-8'))